"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.createCompatFile = exports.processCompatData = exports.processCompatDataObject = void 0;
const browser_compat_data_1 = __importDefault(require("@mdn/browser-compat-data"));
const fs_1 = __importDefault(require("fs"));
const path_1 = __importDefault(require("path"));
const CSS_GLOB = "**/*.{css,scss}";
const HTML_GLOB = "**/*.html";
const JS_GLOB = "**/*.{ts,js}";
function processCompatDataObject(data, prefix = "", suffix = "") {
    const compatIssues = {};
    for (const prop of Object.keys(data)) {
        let hasIssue = false;
        if (!data[prop].__compat) {
            continue;
        }
        const { status, support, mdn_url } = data[prop].__compat;
        const itemCompatIssues = {
            deprecated: false,
            browserIssues: [],
            mdn_url,
        };
        if (status?.deprecated) {
            itemCompatIssues.deprecated = true;
            hasIssue = true;
        }
        else {
            for (const [name, data] of Object.entries(support)) {
                const isSupported = !Array.isArray(data)
                    ? data.version_added && !data.version_last && !data.flags
                    : data.some((obj) => obj.version_added && !obj.version_last && !obj.flags);
                if (!isSupported) {
                    itemCompatIssues.browserIssues = [
                        ...itemCompatIssues.browserIssues,
                        name,
                    ];
                    hasIssue = true;
                }
            }
        }
        if (hasIssue) {
            compatIssues[`${prefix}${prop}${suffix}`] = itemCompatIssues;
        }
    }
    return compatIssues;
}
exports.processCompatDataObject = processCompatDataObject;
function processCompatData() {
    const cssCompatIssues = {
        ...processCompatDataObject(browser_compat_data_1.default.css["at-rules"], "@"),
        ...processCompatDataObject(browser_compat_data_1.default.css.properties, "", ":"),
        ...processCompatDataObject(browser_compat_data_1.default.css.selectors, ":"),
        ...processCompatDataObject(browser_compat_data_1.default.css.types, "", "\\("),
    };
    const htmlCompatIssues = {
        ...processCompatDataObject(browser_compat_data_1.default.html.elements, "<"),
        ...processCompatDataObject(browser_compat_data_1.default.html.global_attributes, "", "="),
    };
    const jsCompatIssues = {
        ...processCompatDataObject(browser_compat_data_1.default.javascript.builtins, "", "\\("),
        ...processCompatDataObject(browser_compat_data_1.default.api, "", "\\("),
    };
    return {
        [CSS_GLOB]: cssCompatIssues,
        [HTML_GLOB]: htmlCompatIssues,
        [JS_GLOB]: jsCompatIssues,
    };
}
exports.processCompatData = processCompatData;
function createCompatFile() {
    const jsonString = JSON.stringify(processCompatData(), null, 2);
    const filePath = path_1.default.join(__filename, "../compat-issues.json");
    fs_1.default.writeFileSync(filePath, jsonString, "utf-8");
    fs_1.default.chmodSync(filePath, "644");
}
exports.createCompatFile = createCompatFile;
createCompatFile();
//# sourceMappingURL=compat-issues.js.map